@@ -3,9 +3,10 @@
 ## to Rayleigh sigma using lookup table from 1000000 runs for each
 ## combination of n*nGroups
 ## http://ballistipedia.com/index.php?title=Range_Statistics
+
 range2sigma <-
-    function(x, stat="ES", n=5, nGroups=1, CIlevel=0.95, collapse=TRUE,
-             dstTarget=100, conversion="m2cm") {
+function(x, stat="ES", n=5, nGroups=1, CIlevel=0.95, collapse=TRUE,
+         dstTarget, conversion) {
     n       <- as.integer(n[1])
     nGroups <- as.integer(nGroups[1])
     stopifnot(all(x > 0),
@@ -15,7 +16,7 @@ range2sigma <-
     stat <- match.arg(toupper(stat), choices=c("ES", "FOM", "D"), several.ok=TRUE)
     argL <- recycle(x, stat)
     x    <- argL[[1]]
-    stat <- argL[[2]]
+    stat <- c(ES="ES", FOM="FoM", D="D")[argL[[2]]]
     x    <- setNames(x, stat)
 
     ## check if CIlevel is given in percent
@@ -24,6 +25,22 @@ range2sigma <-
         warning(c("CIlevel must be in (0,1) and was set to ", CIlevel))
     }
 
+    dstTarget <- if(missing(dstTarget)    ||
+                    all(is.na(dstTarget)) ||
+                    (length(unique(dstTarget)) > 1L)) {
+        NA_real_
+    } else {
+        unique(dstTarget)
+    }
+    
+    conversion <- if(missing(conversion)    ||
+                     all(is.na(conversion)) ||
+                     (length(unique(conversion)) > 1L)) {
+        NA_character_
+    } else {
+        unique(conversion)
+    }
+    
     alpha    <- 1 - CIlevel
     idxGroup <- which(shotGroups::DFdistr$nGroups == nGroups)
     haveN    <- unique(shotGroups::DFdistr$n[idxGroup])
@@ -35,10 +52,8 @@ range2sigma <-
         ## can use lookup table for sigma estimate
         idx <- which((shotGroups::DFdistr$n       == n) &
                      (shotGroups::DFdistr$nGroups == nGroups))
-        M   <- setNames(numeric(length(x)), stat)
-        M[names(M) %in% "ES"]  <- shotGroups::DFdistr$ES_M[idx]
-        M[names(M) %in% "FOM"] <- shotGroups::DFdistr$FoM_M[idx]
-        M[names(M) %in% "D"]   <- shotGroups::DFdistr$D_M[idx]
+        M <- data.matrix(shotGroups::DFdistr[idx, paste0(stat, "_M"), drop=FALSE])
+        M <- setNames(c(M), stat)
 
         ## for Grubbs-Patnaik ES-CI approximation
         if(!(CIlevel %in% haveCI)) {
@@ -49,14 +64,14 @@ range2sigma <-
             ES_KURT <- shotGroups::DFdistr$ES_KURT[idx]
         }
     } else {
-        ## spline interpolation for sigma estimate - M is monotonically increasing
+        ## spline interpolation for sigma estimate - M is monotonically increasing in n
         warning("Rayleigh sigma estimate based on monotone spline interpolation for n")
 
         ## only interpolate for requested number of groups
         M <- setNames(numeric(length(x)), stat)
-        M[names(M) %in% "ES"]  <- splinefun(haveN, shotGroups::DFdistr$ES_M[idxGroup],  method="monoH.FC")(n)
-        M[names(M) %in% "FOM"] <- splinefun(haveN, shotGroups::DFdistr$FoM_M[idxGroup], method="monoH.FC")(n)
-        M[names(M) %in% "D"]   <- splinefun(haveN, shotGroups::DFdistr$D_M[idxGroup],   method="monoH.FC")(n)
+        M[names(M) == "ES"]  <- splinefun(haveN, shotGroups::DFdistr$ES_M[idxGroup],  method="monoH.FC")(n)
+        M[names(M) == "FoM"] <- splinefun(haveN, shotGroups::DFdistr$FoM_M[idxGroup], method="monoH.FC")(n)
+        M[names(M) == "D"]   <- splinefun(haveN, shotGroups::DFdistr$D_M[idxGroup],   method="monoH.FC")(n)
 
         ## spline interpolation for Grubbs-Patnaik ES-CI approximation
         ## M is monotonically increasing, but V, SKEW, KURT are not
@@ -73,31 +88,31 @@ range2sigma <-
     sigma <- x/M
 
     ## need extreme spread for sigma CI
-    xES  <- setNames(x[names(x) %in% "ES"],  NULL)
-    xFoM <- setNames(x[names(x) %in% "FOM"], NULL)
-    xD   <- setNames(x[names(x) %in% "D"],   NULL)
+    xES  <- setNames(x[names(x) == "ES"],  NULL)
+    xFoM <- setNames(x[names(x) == "FoM"], NULL)
+    xD   <- setNames(x[names(x) == "D"],   NULL)
     if(CIlevel %in% haveCI) {
         CIlo <- sprintf("%04.1f", round((1-(alpha/2))*100, digits=1))
-        CIhi <- sprintf("%04.1f", round(   (alpha/2) *100, digits=1))
+        CIup <- sprintf("%04.1f", round(   (alpha/2) *100, digits=1))
         if(n %in% haveN) {
             ES_CIlo  <-  xES/shotGroups::DFdistr[[sub("\\.", "", paste0("ES_Q",  CIlo))]][idx]
-            ES_CIhi  <-  xES/shotGroups::DFdistr[[sub("\\.", "", paste0("ES_Q",  CIhi))]][idx]
+            ES_CIup  <-  xES/shotGroups::DFdistr[[sub("\\.", "", paste0("ES_Q",  CIup))]][idx]
             FoM_CIlo <- xFoM/shotGroups::DFdistr[[sub("\\.", "", paste0("FoM_Q", CIlo))]][idx]
-            FoM_CIhi <- xFoM/shotGroups::DFdistr[[sub("\\.", "", paste0("FoM_Q", CIhi))]][idx]
+            FoM_CIup <- xFoM/shotGroups::DFdistr[[sub("\\.", "", paste0("FoM_Q", CIup))]][idx]
             D_CIlo   <-   xD/shotGroups::DFdistr[[sub("\\.", "", paste0("D_Q",   CIlo))]][idx]
-            D_CIhi   <-   xD/shotGroups::DFdistr[[sub("\\.", "", paste0("D_Q",   CIhi))]][idx]
+            D_CIup   <-   xD/shotGroups::DFdistr[[sub("\\.", "", paste0("D_Q",   CIup))]][idx]
         } else {
             ES_CIlo  <-  xES/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("ES_Q",  CIlo))]][idxGroup],
                                        method="fmm")(n)
-            ES_CIhi  <-  xES/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("ES_Q",  CIhi))]][idxGroup],
+            ES_CIup  <-  xES/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("ES_Q",  CIup))]][idxGroup],
                                        method="fmm")(n)
             FoM_CIlo <- xFoM/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("FoM_Q", CIlo))]][idxGroup],
                                        method="fmm")(n)
-            FoM_CIhi <- xFoM/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("FoM_Q", CIhi))]][idxGroup],
+            FoM_CIup <- xFoM/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("FoM_Q", CIup))]][idxGroup],
                                        method="fmm")(n)
             D_CIlo   <-   xD/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("D_Q",   CIlo))]][idxGroup],
                                        method="fmm")(n)
-            D_CIhi   <-   xD/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("D_Q",   CIhi))]][idxGroup],
+            D_CIup   <-   xD/splinefun(haveN, shotGroups::DFdistr[[sub("\\.", "", paste0("D_Q",   CIup))]][idxGroup],
                                        method="fmm")(n)
         }
     } else {
@@ -110,43 +125,47 @@ range2sigma <-
             # m <- ES_M^2 + ES_V
             # v <- ES_KURT*ES_V^2 + 4*ES_SKEW*sqrt(ES_V)^3*ES_M + 4*ES_V*ES_M^2 - ES_V^2
             ES_CIlo  <- xES/qChisqGrubbs(1-(alpha/2), m=m, v=v, n=2*m^2/v)
-            ES_CIhi  <- xES/qChisqGrubbs(   alpha/2,  m=m, v=v, n=2*m^2/v)
+            ES_CIup  <- xES/qChisqGrubbs(   alpha/2,  m=m, v=v, n=2*m^2/v)
             FoM_CIlo <- NULL
-            FoM_CIhi <- NULL
+            FoM_CIup <- NULL
             D_CIlo   <- NULL
-            D_CIhi   <- NULL
+            D_CIup   <- NULL
         } else {
             warning("CI from Grubbs-Patnaik approximation requires extreme spread")
             ES_CIlo  <- NULL
-            ES_CIhi  <- NULL
+            ES_CIup  <- NULL
             FoM_CIlo <- NULL
-            FoM_CIhi <- NULL
+            FoM_CIup <- NULL
             D_CIlo   <- NULL
-            D_CIhi   <- NULL
+            D_CIup   <- NULL
         }
     }
 
     ## convert CIs to MOA
     sigma <- makeMOA(sigma, dst=dstTarget, conversion=conversion)
+    if(is.matrix(sigma)) {
+        colnames(sigma) <- paste0(names(x), "_", round(x, digits=3))
+    }
+    
     sigmaESCI  <- lapply(seq_along(ES_CIlo),  function(i) {
-        makeMOA(c("sigma ("=ES_CIlo[i], "sigma )" =ES_CIhi[i]),
+        makeMOA(c("sigma ("=ES_CIlo[i], "sigma )" =ES_CIup[i]),
                 dst=dstTarget, conversion=conversion) })
     sigmaESCI  <- if(length(sigmaESCI) > 0L) {
-        setNames(sigmaESCI,  paste0("ES",  round(xES, digits=2)))
+        setNames(sigmaESCI,  paste0("ES_",  round(xES, digits=2)))
     } else { NULL }
 
     sigmaFoMCI <- lapply(seq_along(FoM_CIlo), function(i) {
-        makeMOA(c("sigma ("=FoM_CIlo[i], "sigma )"=FoM_CIhi[i]),
+        makeMOA(c("sigma ("=FoM_CIlo[i], "sigma )"=FoM_CIup[i]),
                 dst=dstTarget, conversion=conversion) })
     sigmaFoMCI <- if(length(sigmaFoMCI) > 0L) {
-        setNames(sigmaFoMCI, paste0("FoM", round(xFoM, digits=2)))
+        setNames(sigmaFoMCI, paste0("FoM_", round(xFoM, digits=2)))
     } else { NULL }
 
     sigmaDCI   <- lapply(seq_along(D_CIlo),   function(i) {
-        makeMOA(c("sigma ("=D_CIlo[i], "sigma )"  =D_CIhi[i]),
+        makeMOA(c("sigma ("=D_CIlo[i], "sigma )"  =D_CIup[i]),
                 dst=dstTarget, conversion=conversion) })
     sigmaDCI   <- if(length(sigmaDCI) > 0L) {
-        setNames(sigmaDCI,   paste0("D",   round(xD,   digits=2)))
+        setNames(sigmaDCI,   paste0("D_",   round(xD,   digits=2)))
     } else { NULL }
 
     ## weed out non existing CIs
@@ -165,3 +184,52 @@ range2sigma <-
     Filter(function(l) { !is.null(l) && (length(l) > 0L) },
            list(sigma=sigma, sigmaCI=sigmaCI))
 }
+
+range2CEP <-
+function(x, stat="ES", n=5, nGroups=1, CEPlevel=0.5, CIlevel=0.95,
+         collapse=TRUE, dstTarget, conversion) {
+    sigma <- range2sigma(x=x, stat=stat, n=n, nGroups=nGroups,
+                         CIlevel=CIlevel, collapse=FALSE,
+                         dstTarget=dstTarget, conversion=conversion)
+    CEP <- qRayleigh(CEPlevel, scale=sigma$sigma)
+    CEP <- if(is.matrix(sigma$sigma)) {
+        dim(CEP)      <- dim(sigma$sigma)
+        rownames(CEP) <- rownames(sigma$sigma)
+        colnames(CEP) <- gsub("sigma", "CEP", colnames(sigma$sigma))
+        CEP
+    } else {
+        setNames(CEP, names(sigma$sigma))
+    }
+    
+    if(hasName(sigma, "sigmaCI")) {
+        CEPCI <- lapply(sigma$sigmaCI, function(y) {
+            lapply(y, function(z) {
+                res <- qRayleigh(CEPlevel, scale=z)
+                if(is.matrix(z)) {
+                    dim(res)      <- dim(z)
+                    rownames(res) <- rownames(z)
+                    colnames(res) <- gsub("sigma", "CEP", colnames(z))
+                }
+                
+                res
+            })
+        })
+
+        list(CEP=CEP, CEPCI=CEPCI)
+    } else {
+        list(CEP=CEP)
+    }
+
+    ## collapse sigmaCI list if required and possible
+    if(hasName(sigma, "sigmaCI") && collapse) {
+        for(i in seq_along(CEPCI)) {
+            if(length(CEPCI[[i]]) == 1L) { CEPCI[[i]] <- CEPCI[[c(i, 1)]] }
+        }
+        
+        if(length(CEPCI) == 1L) { CEPCI <- CEPCI[[1]] }
+        
+        list(CEP=CEP, CEPCI=CEPCI)
+    } else {
+        list(CEP=CEP)
+    }
+}
